Working with tiles and merging polygons
=========================================

.. automodule:: histomicstk.annotations_and_masks.polygon_merger
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: histomicstk.annotations_and_masks.polygon_merger_v2
    :members:
    :undoc-members:
    :show-inheritance:
